==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/gr/toolbar.py <==
# Greek lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Νέο έγγραφο",
    "actions_accessible_name_new_document": "Νέο έγγραφο",
    "actions_label_open": "Άνοιγμα",
    "actions_accessible_name_open": "Άνοιγμα εγγράφου",
    "actions_label_save": "Αποθήκευση",
    "actions_accessible_name_save": "Αποθήκευση εγγράφου",
    "actions_label_save_as": "Αποθήκευση ως",
    "actions_accessible_name_save_as": "Αποθήκευση ως αντίγραφο εγγράφου",
    "actions_label_sync": "Συγχρονισμός",
    "actions_accessible_name_sync": "Συγχρονισμός εγγράφου με εξωτερική αποθήκευση",
    "actions_label_edit": "Επεξεργασία",
    "actions_accessible_name_edit": "Επεξεργασία αρχείου",
    "actions_label_source": "Πηγή",
    "actions_accessible_name_source": "Κώδικας πηγής",
    "actions_label_encrypt": "Κρυπτογράφηση",
    "actions_accessible_name_encrypt": "Κρυπτογράφηση αρχείου",
    "actions_label_decrypt": "Αποκρυπτογράφηση",
    "actions_accessible_name_decrypt": "Αποκρυπτογράφηση αρχείου",
    "actions_label_bold": "Έντονα",
    "actions_accessible_name_bold": "Μορφή έντονου κειμένου",
    "actions_label_italic": "Πλάγια",
    "actions_accessible_name_italic": "Μορφή πλάγιου κειμένου",
    "actions_label_underline": "Υπογράμμιση",
    "actions_accessible_name_underline": "Μορφή υπογεγραμμένου κειμένου",
    "actions_label_strikethrough": "Διαγράμμιση",
    "actions_accessible_name_strikethrough": "Μορφή διαγραμμισμένου κειμένου",
    "actions_label_blockquote": "Παράθεση",
    "actions_accessible_name_blockquote": "Μορφή κειμένου παράθεσης",
    "actions_label_color_picker": "Επιλογέας χρώματος",
    "actions_accessible_name_color_picker": "Επιλογή χρώματος κειμένου",
    "actions_label_ai_assistant": "Βοηθός AI",
    "actions_accessible_name_ai_assistant": "Εκκίνηση Βοηθού AI",
    "actions_label_about": "Πληροφορίες",
    "actions_accessible_name_about": "Πληροφορίες για την εφαρμογή",
    "actions_label_exit": "Έξοδος",
    "actions_accessible_name_exit": "Έξοδος από την εφαρμογή",
    "actions_label_settings": "Ρυθμίσεις",
    "actions_accessible_name_settings": "Ρυθμίσεις εφαρμογής",

    "search_input_label": "Αναζήτηση",
    "search_input_placeholder_text": "κείμενο στο έγγραφο",
    "search_input_accessible_description": "Πεδίο εισόδου αναζήτησης",
    "search_buttons_label_clear": "Καθαρισμός αναζήτησης",
    "search_buttons_accessible_name_clear": "Καθαρισμός πεδίου εισόδου αναζήτησης",
    "search_buttons_label_prev": "Προηγούμενη αναζήτηση",
    "search_buttons_accessible_name_prev": "Προηγούμενο αποτέλεσμα αναζήτησης",
    "search_buttons_label_next": "Επόμενη αναζήτηση",
    "search_buttons_accessible_name_next": "Επόμενο αποτέλεσμα αναζήτησης",
    "search_case_sensitive_label": "Διάκριση πεζών-κεφαλαίων",
    "search_case_sensitive_tooltip": "Αναζήτηση με διάκριση πεζών-κεφαλαίων",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/gr/toolbar.py <==
# Greek lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Νέο έγγραφο",
    "actions_accessible_name_new_document": "Νέο έγγραφο",
    "actions_label_open": "Άνοιγμα",
    "actions_accessible_name_open": "Άνοιγμα εγγράφου",
    "actions_label_save": "Αποθήκευση",
    "actions_accessible_name_save": "Αποθήκευση εγγράφου",
    "actions_label_save_as": "Αποθήκευση ως",
    "actions_accessible_name_save_as": "Αποθήκευση ως αντίγραφο εγγράφου",
    "actions_label_sync": "Συγχρονισμός",
    "actions_accessible_name_sync": "Συγχρονισμός εγγράφου με εξωτερική αποθήκευση",
    "actions_label_edit": "Επεξεργασία",
    "actions_accessible_name_edit": "Επεξεργασία αρχείου",
    "actions_label_source": "Πηγή",
    "actions_accessible_name_source": "Κώδικας πηγής",
    "actions_label_encrypt": "Κρυπτογράφηση",
    "actions_accessible_name_encrypt": "Κρυπτογράφηση αρχείου",
    "actions_label_decrypt": "Αποκρυπτογράφηση",
    "actions_accessible_name_decrypt": "Αποκρυπτογράφηση αρχείου",
    "actions_label_bold": "Έντονα",
    "actions_accessible_name_bold": "Μορφή έντονου κειμένου",
    "actions_label_italic": "Πλάγια",
    "actions_accessible_name_italic": "Μορφή πλάγιου κειμένου",
    "actions_label_underline": "Υπογράμμιση",
    "actions_accessible_name_underline": "Μορφή υπογεγραμμένου κειμένου",
    "actions_label_strikethrough": "Διαγράμμιση",
    "actions_accessible_name_strikethrough": "Μορφή διαγραμμισμένου κειμένου",
    "actions_label_blockquote": "Παράθεση",
    "actions_accessible_name_blockquote": "Μορφή κειμένου παράθεσης",
    "actions_label_color_picker": "Επιλογέας χρώματος",
    "actions_accessible_name_color_picker": "Επιλογή χρώματος κειμένου",
    "actions_label_ai_assistant": "Βοηθός AI",
    "actions_accessible_name_ai_assistant": "Εκκίνηση Βοηθού AI",
    "actions_label_about": "Πληροφορίες",
    "actions_accessible_name_about": "Πληροφορίες για την εφαρμογή",
    "actions_label_exit": "Έξοδος",
    "actions_accessible_name_exit": "Έξοδος από την εφαρμογή",
    "actions_label_settings": "Ρυθμίσεις",
    "actions_accessible_name_settings": "Ρυθμίσεις εφαρμογής",

    "search_input_label": "Αναζήτηση",
    "search_input_placeholder_text": "Αναζήτηση κειμένου στο έγγραφο",
    "search_input_accessible_description": "Πεδίο εισόδου αναζήτησης",
    "search_buttons_label_clear": "Καθαρισμός αναζήτησης",
    "search_buttons_accessible_name_clear": "Καθαρισμός πεδίου εισόδου αναζήτησης",
    "search_buttons_label_prev": "Προηγούμενη αναζήτηση",
    "search_buttons_accessible_name_prev": "Προηγούμενο αποτέλεσμα αναζήτησης",
    "search_buttons_label_next": "Επόμενη αναζήτηση",
    "search_buttons_accessible_name_next": "Επόμενο αποτέλεσμα αναζήτησης",
    "search_case_sensitive_accessible_name": "Διάκριση πεζών-κεφαλαίων",
    "search_case_sensitive_tooltip": "Αναζήτηση με διάκριση πεζών-κεφαλαίων",
}
